@@ -1,6 +1,3 @@
-library(dplyr)
-library(sf)
-
 NZ_coast <- hm_get_test("coast")
 NZ_buffer30 <- hm_get_test("buffer")
 NZ_Buller_buffer40 <- hm_get_test("nofly")
@@ -14,23 +11,23 @@ NZ_routes <- hm_get_test("route")
 
 # quick summary for test purposes
 summarise_routes_for_test <- function(r){
-  r %>%
+  r |>
     # wkt is machine-dependent so just extract length/area
-    mutate(across(c(gc, crow), st_length),
-         gc_length = gc) %>%
-    mutate(envelope = st_area(envelope)) %>%
-    sf::st_drop_geometry() %>%
-    group_by(fullRouteID) %>%
+    dplyr::mutate(dplyr::across(c(gc, crow), st_length),
+         gc_length = gc) |>
+    dplyr::mutate(envelope = sf::st_area(envelope)) |>
+    sf::st_drop_geometry() |>
+    dplyr::group_by(fullRouteID) |>
     # test on key outputs, not on detail of table
-    summarise(across(c(time_h, gc_length, crow, envelope), sum, na.rm = TRUE)) %>%
+    dplyr::summarise(dplyr::across(c(time_h, gc_length, crow, envelope), sum, na.rm = TRUE)) |>
     # and round to 3 sig figs
-    mutate(across(c(time_h, gc_length, crow, envelope), signif, 3))
+    dplyr::mutate(dplyr::across(c(time_h, gc_length, crow, envelope), signif, 3))
 }
 
 test_that("Route envelope", {
   ac <- make_aircraft(warn = FALSE)
-  ap <- make_airports()
-  z <- make_route_envelope(ac[1,], make_AP2("EGLL","KJFK",ap),
+  ap <- make_airports(warn = FALSE)
+  z <- make_route_envelope(ac[1,], make_AP2("EGLL","KJFK", ap),
                            envelope_points = 50)
   expect_type(z, "list")
   expect_s3_class(z, "sfc_POLYGON")
@@ -41,7 +38,7 @@ test_that("Route envelope", {
 # adding fields later, which is likely
 # so - add fields but don't fiddle with the list of test routes ;-)
 test_that("Route summary", {
-  ap <- make_airports(crs=crs_Pacific)
+  ap <- make_airports(crs=crs_Pacific, warn = FALSE)
   rs1 <- summarise_routes(NZ_routes, ap)
   expect_equal(rs1[1, ]$refuel_ap, "NZWN")
   expect_equal(rs1[2, ]$M084_h, 1.69)
@@ -66,7 +63,7 @@ test_that("find_leg catches input error",{
   # need to load some of the built-in data
   aircraft <- make_aircraft(warn = FALSE)
   # airports <- make_airports()
-  airports <- make_airports(crs = crs_Pacific)
+  airports <- make_airports(crs = crs_Pacific, warn = FALSE)
   options("quiet" = old_quiet)
   # for visual check:
   # ggplot(NZ_buffer30) + geom_sf() + geom_sf(data = routes$gc)
@@ -87,21 +84,21 @@ test_that("find_route works with subsonic option",{
   hm_clean_cache() #start without cache
   # need to load some of the built-in data
   aircraft <- make_aircraft(warn = FALSE)
-  airports <- make_airports(crs = crs_Pacific)
+  airports <- make_airports(crs = crs_Pacific, warn = FALSE)
 
   # test with parallel subsonic aircraft
   # just ditch the output
-  invisible(capture.output(
+  suppressMessages(
     routes <- find_route(aircraft[1, ],
                        make_AP2("NZGS", "NZDN", airports),
                        fat_map = NZ_buffer30,
                        route_grid = NZ_grid,
                        ap_loc = airports,
-                       cf_subsonic = aircraft[3, ]) %>%
+                       cf_subsonic = aircraft[3, ]) |>
        summarise_routes_for_test()
-  ))
+  )
   # test a couple of rows
-  expect_known_value(routes, "known/test_route_subsonic_NZGS_NZDN",
+  expect_snapshot_value(routes, style = "serialize",
                      tolerance = 0.05)
 
   # and test saving of cache
@@ -123,8 +120,8 @@ test_that("Find multiple routes for multiple aircraft",{
   hm_clean_cache() #start without cache
   # need to load some of the built-in data
   aircraft <- make_aircraft(warn = FALSE)
-  airports <- make_airports(crs = crs_Pacific)
-  refuel_ap <- airports %>%
+  airports <- make_airports(crs = crs_Pacific, warn = FALSE)
+  refuel_ap <- airports |>
     filter(APICAO == "NZWN")
 
   ap2 <- as.data.frame(matrix(c("NZAA","NZCH","NZAA","NZDN"),
@@ -135,11 +132,11 @@ test_that("Find multiple routes for multiple aircraft",{
     routes <- find_routes(ac, ap2, aircraft, airports,
                         fat_map = NZ_buffer30,
                         route_grid = NZ_grid,
-                        refuel = refuel_ap) %>%
+                        refuel = refuel_ap) |>
       summarise_routes_for_test()
   ))
   # just test a sample
-  expect_known_value(routes, "known/test_multiroute",
+  expect_snapshot_value(routes, style = "serialize",
                      tolerance = 0.05)
 
   # and again with a no-fly zone - and just one AP2
@@ -148,11 +145,11 @@ test_that("Find multiple routes for multiple aircraft",{
                           fat_map = NZ_buffer30,
                           route_grid = NZ_grid,
                           refuel = refuel_ap,
-                          avoid = NZ_Buller_buffer40)  %>%
+                          avoid = NZ_Buller_buffer40)  |>
       summarise_routes_for_test()
   ))
   # check one row from each route
-  expect_known_value(routes, "known/test_multiroute_nofly",
+  expect_snapshot_value(routes, style = "serialize",
                      tolerance = 0.05)
 
   # check for faulty airports
